@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -91,7 +91,7 @@ add_arg_s (	argument_t *e,
 
 	if (e->idx + 1 >= e->length) {
 		tmp = (char **) realloc (e->arg,
-					(e->length + 10) * sizeof (char **));
+					(e->length + 10) * sizeof (char *));
 		if (tmp == NULL) {
 			return -1;
 		}
