@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2011 Herve Quatremain
+   Copyright (C) 2011-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -85,6 +85,7 @@ extern int errno;
 #include <lib_functions.h>
 #include <utils.h>
 #include <lwc_log.h>
+#include <xmem.h>
 #include <cert_utils.h>
 
 
@@ -98,8 +99,7 @@ extern int errno;
  * one (`newc') in the provided string.
  *
  * Return:
- *   A newly allocated string with all the occurences of `oldc' replaced OR
- *   NULL in case of memory allocation error.
+ *   A newly allocated string with all the occurences of `oldc' replaced
  */
 static char *
 tr (const char *instr, const char *oldc, const char *newc)
@@ -107,16 +107,14 @@ tr (const char *instr, const char *oldc, const char *newc)
 	char *outstr;
 	size_t i, j, len_newc;
 
+
 #if HAVE_ASSERT_H
 	assert (instr != NULL && oldc != NULL && newc != NULL);
 #endif
 
-	outstr = (char *) malloc (schedwi_strlen (instr) + 1);
-	if (outstr == NULL) {
-		return NULL;
-	}
+	outstr = (char *) xmalloc (strlen (instr) + 1);
 
-	len_newc = schedwi_strlen (newc);
+	len_newc = strlen (newc);
 	for (i = 0; instr[i] != '\0'; i++) {
 		outstr[i] = instr[i];
 		for (j = 0; oldc[j] != '\0'; j++) {
@@ -136,8 +134,7 @@ tr (const char *instr, const char *oldc, const char *newc)
  * Serialize a PEM encoded string (replace \n by @)
  *
  * Return:
- *   The serialized string (to be freed by free()) OR
- *   NULL in case of memory allocation error.
+ *   The serialized string (to be freed by free())
  */
 char *
 PEM2string (const char *pemstr)
@@ -150,8 +147,7 @@ PEM2string (const char *pemstr)
  * Unserialize a PEM encoded string (replace @ by \n)
  *
  * Return:
- *   The unserialized PEM string (to be freed by free()) OR
- *   NULL in case of memory allocation error.
+ *   The unserialized PEM string (to be freed by free())
  */
 char *
 string2PEM (const char *pemstr)
@@ -298,6 +294,7 @@ generate_private_key_int ()
 	gnutls_x509_privkey_t key;
 	int ret;
 
+
 	ret = gnutls_x509_privkey_init (&key);
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
@@ -335,6 +332,7 @@ write_private_key (	gnutls_x509_privkey_t key, const char *outfile,
 	size_t size;
 	FILE *file;
 
+
 	if (key == NULL || outfile == NULL) {
 		return 0;
 	}
@@ -390,6 +388,7 @@ generate_private_key (const char *outfile, const char *user, const char *group)
 {
 	gnutls_x509_privkey_t key;
 
+
 #if HAVE_ASSERT_H
 	assert (outfile != NULL);
 #endif
@@ -418,7 +417,8 @@ generate_private_key (const char *outfile, const char *user, const char *group)
 static int
 string_to_ip (unsigned char *ip, const char *str)
 {
-	int len = schedwi_strlen (str);
+	int len = strlen (str);
+
 
 #if defined AF_INET6
 	if (strchr (str, ':') != NULL || len > 16)
@@ -474,8 +474,7 @@ generate_request (gnutls_x509_privkey_t key,
 	/* Set the DN */
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 					GNUTLS_OID_X520_COUNTRY_NAME, 0,
-					COUNTRY,
-					schedwi_strlen (COUNTRY));
+					COUNTRY, strlen (COUNTRY));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COUNTRY (%s): %s"),
@@ -486,8 +485,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 					GNUTLS_OID_X520_ORGANIZATION_NAME, 0,
-					ORGANIZATION,
-					schedwi_strlen (ORGANIZATION));
+					ORGANIZATION, strlen (ORGANIZATION));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATION (%s): %s"),
@@ -498,7 +496,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_ORGANIZATIONAL_UNIT_NAME, 0,
-				OU, schedwi_strlen (OU));
+				OU, strlen (OU));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the ORGANIZATIONAL UNIT (%s): %s"),
@@ -509,8 +507,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 					GNUTLS_OID_X520_LOCALITY_NAME, 0,
-					LOCALITY,
-					schedwi_strlen (LOCALITY));
+					LOCALITY, strlen (LOCALITY));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the LOCALITY (%s): %s"),
@@ -521,8 +518,7 @@ generate_request (gnutls_x509_privkey_t key,
 
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 				GNUTLS_OID_X520_STATE_OR_PROVINCE_NAME, 0,
-				STATE,
-				schedwi_strlen (STATE));
+				STATE, strlen (STATE));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the STATE (%s): %s"),
@@ -534,7 +530,7 @@ generate_request (gnutls_x509_privkey_t key,
 	/* The first name in the array is used as CN */
 	ret = gnutls_x509_crq_set_dn_by_oid (crq,
 					GNUTLS_OID_X520_COMMON_NAME, 0,
-					*dnsnames, schedwi_strlen (*dnsnames));
+					*dnsnames, strlen (*dnsnames));
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
 			_("SSL: Cannot set the COMMON NAME (%s): %s"),
@@ -551,10 +547,10 @@ generate_request (gnutls_x509_privkey_t key,
 	 * data have to be stored, we'll then try to choose the best we can
 	 * the ones that are going to make it in the certificate.
 	 */
-	len = 	  schedwi_strlen (dnsnames[0]) * 2 /* In the CN and alt name */
-		+ ((ip != NULL) ? schedwi_strlen (ip) : 0);
+	len = 	  strlen (dnsnames[0]) * 2 /* In the CN and alt name */
+		+ ((ip != NULL) ? strlen (ip) : 0);
 	for (i = 1; dnsnames[i] != NULL; i++) {
-		len += schedwi_strlen (dnsnames[i]);
+		len += strlen (dnsnames[i]);
 	}
 
 	for (i = 0; dnsnames[i] != NULL; i++) {
@@ -566,7 +562,7 @@ generate_request (gnutls_x509_privkey_t key,
 				    || strcmp (dnsnames[i], "localhost") == 0
 				    || strcmp (dnsnames[i], "localhost6") == 0)
 				{
-					len -= schedwi_strlen (dnsnames[i]);
+					len -= strlen (dnsnames[i]);
 					if (   (ip == NULL || *ip == '\0')
 					    && isdigit (dnsnames[i][0]) != 0)
 					{
@@ -582,7 +578,7 @@ generate_request (gnutls_x509_privkey_t key,
 	 		ret = gnutls_x509_crq_set_subject_alt_name (crq,
 						GNUTLS_SAN_DNSNAME,
 						dnsnames[i],
-						schedwi_strlen (dnsnames[i]),
+						strlen (dnsnames[i]),
 						GNUTLS_FSAN_APPEND);
 			if (ret < 0) {
 				lwc_writeLog (LOG_ERR,
@@ -620,17 +616,11 @@ generate_request (gnutls_x509_privkey_t key,
 	/* Email */
 /* As the crq buffer has a limited size, just skip the useless Email
 
-	s = (char *) malloc (	  schedwi_strlen(CSR_EMAIL_PREFIX)
-				+ schedwi_strlen(*dnsnames) + 1);
-	if (s == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		gnutls_x509_crq_deinit (crq);
-		return NULL;
-	}
+	s = (char *) xmalloc(strlen(CSR_EMAIL_PREFIX) + strlen(*dnsnames) + 1);
 	strcpy (s, CSR_EMAIL_PREFIX);
 	strcat (s, *dnsnames);
 	ret = gnutls_x509_crq_set_subject_alt_name (crq, GNUTLS_SAN_RFC822NAME,
-						s, schedwi_strlen (s),
+						s, strlen (s),
 						GNUTLS_FSAN_APPEND);
 	if (ret < 0) {
 		lwc_writeLog (LOG_ERR,
@@ -709,7 +699,7 @@ generate_request (gnutls_x509_privkey_t key,
 			return NULL;
 		}
 		ret = gnutls_x509_crq_privkey_sign (	crq, abs_key,
-							GNUTLS_DIG_SHA1, 0);
+							GNUTLS_DIG_SHA256, 0);
 		gnutls_privkey_deinit (abs_key);
 	}
 #endif
@@ -757,6 +747,7 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 	gnutls_x509_crt_t cert;
 	gnutls_x509_crq_t crq;
 
+
 	if (t == CERT) {
 		cert = (gnutls_x509_crt_t) cert_or_crq;
 		crq = NULL;
@@ -848,67 +839,6 @@ my_gnutls_x509_crt_check_hostname (	void *cert_or_crq, type_data t,
 }
 
 
-/*
- * Read a file and return a newly allocated string with the content,
- * and set `*length' to the length of the string.  The string is
- * zero-terminated, but the terminating zero byte is not counted in
- * `*length'.
- *
- * Return:
- *   The content of the file (to be freed by free()) OR
- *   NULL in case of error (`*length' is undefined). A message has been logged.
- */
-char *
-read_file (const char *filename, size_t *length)
-{
-	struct stat stat_str;
-	FILE *f;
-	char *file_content;
-
-#if HAVE_ASSERT_H
-	assert (filename != NULL);
-#endif
-
-	/* Retrieve the file size */
-	if (stat (filename, &stat_str) != 0) {
-		lwc_writeLog (	LOG_ERR, _("%s: %s"),
-				filename, strerror (errno));
-		return NULL;
-	}
-
-	/* Create a buffer for reading the whole file */
-	file_content = (char *) malloc (stat_str.st_size + 1);
-	if (file_content == NULL) {
-		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
-		return NULL;
-	}
-
-	/* Open and read the whole file */
-	f = fopen (filename, "rb");
-	if (f == NULL) {
-		lwc_writeLog (	LOG_ERR, _("%s: %s"),
-				filename, strerror (errno));
-		free (file_content);
-		return NULL;
-	}
-
-	if (fread (file_content, 1, stat_str.st_size, f) != stat_str.st_size) {
-		lwc_writeLog (	LOG_ERR, _("%s: read error: %s"),
-				filename, strerror (errno));
-		fclose (f);
-		free (file_content);
-		return NULL;
-	}
-	fclose (f);
-
-	file_content[stat_str.st_size] = '\0';
-	if (length != NULL) {
-		*length = stat_str.st_size;
-	}
-	return file_content;
-}
-
-
 /*
  * Load a private key from a file.
  *
@@ -936,6 +866,8 @@ load_private_key (const char *infile)
 	dat.data = (unsigned char *)read_file (infile, &size);
 	dat.size = size;
 	if (dat.data == NULL) {
+		lwc_writeLog (	LOG_ERR, _("%s: read error: %s"),
+				infile, strerror (errno));
 		gnutls_x509_privkey_deinit (key);
 		return NULL;
 	}
