@@ -32,9 +32,9 @@ extern "C" {
 #endif
 
 #if HAVE_PID_T
-extern int add_child OF((pid_t child, const char *job_id));
+extern int add_child OF((pid_t child, const char *job_id, const char *path));
 #else
-extern int add_child OF((int child, const char *job_id));
+extern int add_child OF((int child, const char *job_id, const char *path));
 #endif
 
 #if HAVE_PID_T
