@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2010 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -21,6 +21,10 @@
 
 #include <schedwi.h>
 
+#if HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
 #if STDC_HEADERS
 #include <stdlib.h>
 #include <string.h>
@@ -65,8 +69,10 @@ extern int errno;
 #endif
 
 #include <lib_functions.h>
-#include <conf.h>
 #include <addrmatch.h>
+#include <xmem.h>
+#include <utils.h>
+#include <conf.h>
 
 
 /*
@@ -326,7 +332,7 @@ check_syslog_facility (const char *s)
 	assert (s != NULL);
 #endif
 
-	if (string2facility (s, NULL) != 0){
+	if (string2facility (s, NULL) != 0) {
 		return _("unknown facility name (see syslog(3))");
 	}
 	return NULL;
@@ -357,6 +363,7 @@ is_bool_true (const char *value)
 	return 0;
 }
 
+
 /*
  * Does the string correspond to a boolean FALSE value?
  *
@@ -381,6 +388,7 @@ is_bool_false (const char *value)
 	return 0;
 }
 
+
 /*
  * Check if the provided string contain a boolean value
  *
@@ -397,6 +405,7 @@ check_bool (const char *s)
 	return NULL;
 }
 
+
 /*
  * Check if the provided string contain an integer
  *
@@ -407,13 +416,13 @@ const char *
 check_int (const char *s)
 {
 	char *ptr;
-	long int unused;
+
 
 #if HAVE_ASSERT_H
 	assert (s != NULL);
 #endif
 
-	unused = strtol (s, &ptr, 0);
+	strtol (s, &ptr, 0);
 	while (*ptr != 0 && isspace (*ptr) != 0) {
 		ptr++;
 	}
@@ -423,6 +432,7 @@ check_int (const char *s)
 	return _("invalid integer value");
 }
 
+
 /*
  * Check if the provided string contain an valid directory name
  *
@@ -434,6 +444,7 @@ check_dirname (const char *s)
 {
 	struct stat file_info;
 
+
 #if HAVE_ASSERT_H
 	assert (s != NULL);
 #endif
@@ -450,6 +461,7 @@ check_dirname (const char *s)
 	return NULL;
 }
 
+
 /*
  * Check if the provided string contain an valid address family (any, inet
  * or inet6)
@@ -473,6 +485,7 @@ check_addrfamily (const char *s)
 	return _("the parameter value should be `any', `inet' (use IPv4 only), or `inet6' (use IPv6 only)");
 }
 
+
 /*
  * Check if the provided network list is properly built.
  *
@@ -492,6 +505,7 @@ check_netlist (const char *s)
 	return NULL;
 }
 
+
 /*
  * strtok (see strtok(3)).
  * Differences:
@@ -505,6 +519,7 @@ my_strtok (char *s, char delim)
 	static char *save = NULL;
 	char *end, *ret;
 
+
 	if (s == NULL && save == NULL) {
 		return NULL;
 	}
@@ -519,7 +534,7 @@ my_strtok (char *s, char delim)
 		save = end + 1;
 	}
 	else {
-		end = save + schedwi_strlen (save);
+		end = save + strlen (save);
 		save = NULL;
 	}
 
@@ -533,6 +548,7 @@ my_strtok (char *s, char delim)
 	return ret;
 }
 
+
 /*
  * Destroy (free) the parameter array
  */
@@ -541,6 +557,7 @@ conf_destroy ()
 {
 	int i;
 
+
 	if (params != NULL) {
 		for (i = 0;  params[i].name != NULL; i++) {
 			if (	   params[i].type == STRING
@@ -555,6 +572,7 @@ conf_destroy ()
 	}
 }
 
+
 /*
  * Fill the parameter array by reading the provided configuration file.  If
  * file_name is NULL, no configuration  file is read; the params_array
@@ -562,7 +580,6 @@ conf_destroy ()
  *
  * Return:
  *   0 --> No error
- *  -1 --> Memory allocation error
  *  -2 --> System error while accessing the configuration file (errno is set)
  *  -3 --> Syntax error in the configuration file.  The errors are sent to
  *         stderr
@@ -570,15 +587,14 @@ conf_destroy ()
 int
 conf_init (const char *file_name, conf_param_t *params_array)
 {
-	FILE *fd;
-	struct stat file_info;
 	char *file_content, *save_file_content;
 	char *line, *name, *value, *save_line;
 	const char *err_msg;
-	size_t nb_read, name_len;
-	int save_errno, num_line, nb_errors, i;
+	size_t name_len;
+	int num_line, nb_errors, i;
 	long int facility;
 
+
 #if HAVE_ASSERT_H
 	assert (params_array != NULL);
 #endif
@@ -588,35 +604,12 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		return 0;
 	}
 
-	if (stat (file_name, &file_info) != 0) {
-		return -2;
-	}
-
-	/* Buffer to read all the file in once */
-	file_content = (char *) malloc (file_info.st_size + 1);
+	/* Read the whole file */
+	file_content = read_file (file_name, NULL);
 	if (file_content == NULL) {
-		return -1;
-	}
-
-	fd = fopen (file_name, "r");
-	if (fd == NULL) {
-		free (file_content);
 		return -2;
 	}
 
-	clearerr (fd);
-	nb_read = fread (file_content, 1, file_info.st_size, fd);
-	if (nb_read != (size_t) file_info.st_size && ferror (fd) != 0) {
-		save_errno = errno;
-		free (file_content);
-		fclose (fd);
-		errno = save_errno;
-		return -2;
-	}
-	file_content[nb_read] = '\0';
-
-	fclose (fd);
-
 	conf_destroy ();
 	params = params_array;
 	num_line = nb_errors = 0;
@@ -641,11 +634,9 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (name_len == 0) {
 			/* ie. '= value' (missing parameter name) */
 			nb_errors++;
-			fprintf (stderr, _("%s: syntax error on line %d: "),
-					file_name, num_line);
-			fputs (_("missing parameter name:\n"), stderr);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			fprintf (stderr,
+		_("%s: syntax error on line %d: missing parameter name: %s\n"),
+				file_name, num_line, save_line);
 			continue;
 		}
 
@@ -656,12 +647,9 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (*line != '=') {
 			/* ie. 'name  value' (missing '=') */
 			nb_errors++;
-			fprintf (stderr, _("%s: syntax error on line %d: "),
-					file_name, num_line);
-			fputs (_("missing `=' sign between name and value:\n"),
-					stderr);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			fprintf (stderr,
+_("%s: syntax error on line %d: missing `=' sign between name and value: %s\n"),
+				file_name, num_line, save_line);
 			continue;
 		}
 		line++;
@@ -674,11 +662,9 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (*line == '\0' || *line == '#' || *line == ';') {
 			/* ie. 'name =' (missing value) */
 			nb_errors++;
-			fprintf (stderr, _("%s: syntax error on line %d: "),
-					file_name, num_line);
-			fputs (_("missing value:\n"), stderr);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			fprintf (stderr,
+			_("%s: syntax error on line %d: missing value: %s\n"),
+				file_name, num_line, save_line);
 			continue;
 		}
 
@@ -696,10 +682,8 @@ conf_init (const char *file_name, conf_param_t *params_array)
 		if (params[i].name == NULL) {
 			nb_errors++;
 			fprintf (stderr,
-				_("%s: unknown parameter name on line %d:\n"),
-				file_name, num_line);
-			fputs (save_line, stderr);
-			fputc ('\n', stderr);
+			_("%s: unknown parameter name on line %d: %s\n"),
+					file_name, num_line, save_line);
 			continue;
 		}
 
@@ -709,42 +693,33 @@ conf_init (const char *file_name, conf_param_t *params_array)
 			if (err_msg != 0) {
 				nb_errors++;
 				fprintf (stderr,
-			_("%s: erroneous value parameter on line %d: "),
-					file_name, num_line);
-				fputs (err_msg, stderr);
-				fputs (":\n", stderr);
-				fputs (save_line, stderr);
-				fputc ('\n', stderr);
+		_("%s: erroneous value parameter on line %d: %s: %s\n"),
+					file_name, num_line,
+					err_msg, save_line);
 				continue;
 			}
 		}
 
 		/* Save the parameter */
 		switch (params[i].type) {
-			case INT:
-				params[i].value.value_int = strtol (value, NULL, 0);
-				break;
+		case INT:
+			params[i].value.value_int = strtol (value, NULL, 0);
+			break;
 
-			case BOOL:
-				params[i].value.value_bool = is_bool_true (value);
-				break;
-
-			case STRING:
-				params[i].value.value_string = (char *) malloc (
-						schedwi_strlen (value) + 1);
-				if (params[i].value.value_string == NULL) {
-					free (save_file_content);
-					conf_destroy ();
-					return -1;
-				}
-				strcpy (params[i].value.value_string, value);
-				break;
-			case SYSLOG_FACILITY:
-				facility = -1;
-				string2facility (value, &facility);
-				params[i].value.value_int = facility;
-				break;
+		case BOOL:
+			params[i].value.value_bool = is_bool_true (value);
+			break;
 
+		case STRING:
+			params[i].value.value_string =
+					(char *) xmalloc (strlen (value) + 1);
+			strcpy (params[i].value.value_string, value);
+			break;
+		case SYSLOG_FACILITY:
+			facility = -1;
+			string2facility (value, &facility);
+			params[i].value.value_int = facility;
+			break;
 		}
 		params[i].is_set = 1;
 	}
@@ -756,6 +731,7 @@ conf_init (const char *file_name, conf_param_t *params_array)
 	return 0;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -768,6 +744,7 @@ conf_get_param_string (const char *name, const char **value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
@@ -790,6 +767,7 @@ conf_get_param_string (const char *name, const char **value)
 	return -1;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -802,6 +780,7 @@ conf_get_param_int (const char *name, long int *value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
@@ -831,6 +810,7 @@ conf_get_param_int (const char *name, long int *value)
 	return -1;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -843,6 +823,7 @@ conf_get_param_bool (const char *name, char *value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
@@ -871,6 +852,7 @@ conf_get_param_bool (const char *name, char *value)
 	return -1;
 }
 
+
 /*
  * Get the value associated with the provided parameter name
  *
@@ -883,6 +865,7 @@ conf_get_param_syslog_facility (const char *name, long int *value)
 {
 	int i;
 
+
 	if (params == NULL) {
 		return -1;
 	}
