@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -63,6 +63,7 @@ extern int errno;
 #include <net_utils_init.h>
 #include <lib_functions.h>
 #include <control_groups_linux.h>
+#include <lwc_log.h>
 #include <job_launcher.h>
 
 
@@ -95,6 +96,7 @@ build_errmsg_errno (int errnum, const char *msg, char **out)
 {
 	char *strerr;
 
+
 #if HAVE_ASSERT_H
 	assert (msg != NULL);
 #endif
@@ -165,6 +167,7 @@ get_child_status (int pipe_fd, int child, char **err_msg)
 	int result_errno;
 	child_errcode_t child_err;
 
+
 	/* Read the error code sent by the child */
 	nb_read = read (pipe_fd, &result_errno, sizeof (int));
 	if (nb_read > 0) {
@@ -245,7 +248,8 @@ get_child_status (int pipe_fd, int child, char **err_msg)
  * and manage its return code.
  */
 static void
-launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
+launcher (	job_run_t *j, int status_pipe_father[2], const char *job_id,
+		const char *job_name)
 {
 #if HAVE_PID_T
 	pid_t child;
@@ -256,7 +260,7 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	int status_pipe_child[2], out, err;
 	child_errcode_t child_err;
 	ssize_t nb_read;
-	ssize_t unused;
+	char open_log;
 #if HAVE_SETRLIMIT
 	struct rlimit rlim;
 #endif
@@ -264,6 +268,7 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	int old_nice;
 #endif
 
+
 #if HAVE_ASSERT_H
 	assert (j != NULL);
 #endif
@@ -271,6 +276,7 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	/* Clean the process */
 	destroy_modules ();
 	net_free ();
+	open_log = (char) lwc_logIsFile ();
 	sanitise (status_pipe_father[1]);
 #if HAVE_SETSID
 	setsid();
@@ -283,9 +289,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	 * process can report the error to its father.
 	 */
 	if (pipe (status_pipe_child) != 0) {
-		unused = write (status_pipe_father[1], &errno, sizeof (int));
+		write (status_pipe_father[1], &errno, sizeof (int));
 		child_err = CHILD_PIPE;
-		unused = write (status_pipe_father[1], &child_err,
+		write (status_pipe_father[1], &child_err,
 						sizeof (child_errcode_t));
 		close (status_pipe_father[1]);
 		exit (1);
@@ -293,9 +299,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 
 	child = fork ();
 	if (child < 0) {
-		unused = write (status_pipe_father[1], &errno, sizeof (int));
+		write (status_pipe_father[1], &errno, sizeof (int));
 		child_err = CHILD_FORK;
-		unused = write (status_pipe_father[1], &child_err,
+		write (status_pipe_father[1], &child_err,
 						sizeof (child_errcode_t));
 		close (status_pipe_father[1]);
 		close (status_pipe_child[0]);
@@ -325,18 +331,19 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 			if (j->detach == 0) {
 				/*
 				 * Run the main function of the launcher to
-				 * wait for the ccommand result
+				 * wait for the command result
 				 */
-				launcher_main (child, job_id);
+				launcher_main (	child, job_id, job_name,
+						open_log);
 			}
 			exit (0);
 		}
 
 		/* Send back the error code to the father */
 		waitpid (child, NULL, 0);
-		unused = write (status_pipe_father[1], &result_errno, sizeof (int));
-		unused = write (status_pipe_father[1], &child_err,
-						sizeof (child_errcode_t));
+		write (status_pipe_father[1], &result_errno, sizeof (int));
+		write (	status_pipe_father[1], &child_err,
+			sizeof (child_errcode_t));
 		close (status_pipe_father[1]);
 		exit (1);
 	}
@@ -375,9 +382,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	    && j->nice >= -20 && j->nice <= 19
 	    && setpriority (PRIO_PROCESS, 0, j->nice) != 0)
 	{
-		unused = write (3, &errno, sizeof (int));
+		write (3, &errno, sizeof (int));
 		child_err = CHILD_SETPRIORITY;
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
@@ -393,11 +400,10 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 			rlim.rlim_cur = j->lim;
 			rlim.rlim_max = j->lim;
 			if (setrlimit (RLIMIT_FSIZE, &rlim) != 0) {
-				unused = write (3, &errno, sizeof (int));
+				write (3, &errno, sizeof (int));
 				child_err = CHILD_SETRLIMIT;
-				unused = write (3,
-						&child_err,
-						sizeof (child_errcode_t));
+				write (	3, &child_err,
+					sizeof (child_errcode_t));
 				close (3);
 				exit (1);
 			}
@@ -409,24 +415,24 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 #if HAVE_SETREGID
 	if (setregid (j->gid, j->gid) != 0) {
 		child_err = CHILD_SETGID;
-		unused = write (3, &errno, sizeof (int));
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &errno, sizeof (int));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
 #else
 	if (setgid (j->gid) != 0) {
 		child_err = CHILD_SETGID;
-		unused = write (3, &errno, sizeof (int));
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &errno, sizeof (int));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
 #if HAVE_SETEGID
 	if (setegid (j->gid) != 0) {
 		child_err = CHILD_SETEGID;
-		unused = write (3, &errno, sizeof (int));
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &errno, sizeof (int));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
@@ -437,24 +443,24 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 #if HAVE_SETREUID
 	if (setreuid (j->uid, j->uid) != 0) {
 		child_err = CHILD_SETUID;
-		unused = write (3, &errno, sizeof (int));
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &errno, sizeof (int));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
 #else
 	if (setuid (j->uid) != 0) {
 		child_err = CHILD_SETUID;
-		unused = write (3, &errno, sizeof (int));
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &errno, sizeof (int));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
 #if HAVE_SETEUID
 	if (seteuid (j->uid) != 0) {
 		child_err = CHILD_SETEUID;
-		unused = write (3, &errno, sizeof (int));
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &errno, sizeof (int));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
@@ -464,9 +470,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	/* Change dir */
 #if HAVE_CHDIR
 	if (chdir (j->work) != 0) {
-		unused = write (3, &errno, sizeof (int));
+		write (3, &errno, sizeof (int));
 		child_err = CHILD_CHDIR;
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
@@ -484,9 +490,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 				S_IROTH|S_IWOTH);
 	}
 	if (out < 0) {
-		unused = write (3, &errno, sizeof (int));
+		write (3, &errno, sizeof (int));
 		child_err = CHILD_OPEN;
-		unused = write (3, &child_err, sizeof (child_errcode_t));
+		write (3, &child_err, sizeof (child_errcode_t));
 		close (3);
 		exit (1);
 	}
@@ -503,9 +509,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	if (j->file_stderr == NULL || (j->file_stderr)[0] == '\0') {
 		err = open ("/dev/null", O_WRONLY);
 		if (err < 0) {
-			unused = write (3, &errno, sizeof (int));
+			write (3, &errno, sizeof (int));
 			child_err = CHILD_OPEN;
-			unused = write (3, &child_err, sizeof (child_errcode_t));
+			write (3, &child_err, sizeof (child_errcode_t));
 			close (1);
 			close (3);
 			exit (1);
@@ -526,9 +532,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 					S_IRGRP|S_IWGRP|
 					S_IROTH|S_IWOTH);
 			if (err < 0) {
-				unused = write (3, &errno, sizeof (int));
+				write (3, &errno, sizeof (int));
 				child_err = CHILD_OPEN;
-				unused = write (3, &child_err,
+				write (3, &child_err,
 						sizeof (child_errcode_t));
 				close (1);
 				close (3);
@@ -545,9 +551,9 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
 	execve (j->command, (j->arguments).arg, (j->environ).env);
 
 	/* Error */
-	unused = write (3, &errno, sizeof (int));
+	write (3, &errno, sizeof (int));
 	child_err = CHILD_EXEC;
-	unused = write (3, &child_err, sizeof (child_errcode_t));
+	write (3, &child_err, sizeof (child_errcode_t));
 	close (1);
 	close (2);
 	close (3);
@@ -573,10 +579,12 @@ launcher (job_run_t *j, int status_pipe_father[2], const char *job_id)
  */
 #if HAVE_PID_T
 static int
-exec_command (job_run_t *j, const char *job_id, pid_t *job_pid, char **err_msg)
+exec_command (	job_run_t *j, const char *job_id, pid_t *job_pid,
+		const char *job_name, char **err_msg)
 #else
 static int
-exec_command (job_run_t *j, const char *job_id, int *job_pid, char **err_msg)
+exec_command (	job_run_t *j, const char *job_id, int *job_pid,
+		const char *job_name, char **err_msg)
 #endif
 {
 #if HAVE_PID_T
@@ -588,6 +596,7 @@ exec_command (job_run_t *j, const char *job_id, int *job_pid, char **err_msg)
 	int save_errno;
 	int ret;
 
+
 #if HAVE_ASSERT_H
 	assert (j != NULL);
 #endif
@@ -637,7 +646,7 @@ exec_command (job_run_t *j, const char *job_id, int *job_pid, char **err_msg)
 	/*
 	 * Child
 	 */
-	launcher (j, status_pipe, job_id);
+	launcher (j, status_pipe, job_id, job_name);
 	return 0; /* Never reached - launcher() uses exit()) */
 }
 
@@ -669,6 +678,7 @@ submit_job (	job_parameters_t *j, const char *job_id, int *job_pid,
 	int save_errno, idx;
 	job_run_t jr;
 
+
 	if (j == NULL) {
 		return 0;
 	}
@@ -756,7 +766,7 @@ submit_job (	job_parameters_t *j, const char *job_id, int *job_pid,
 	add_detach_job_run (&jr, j->detach);
 
 	/* Run the command */
-	if (exec_command (&jr, job_id, job_pid, err_msg) != 0) {
+	if (exec_command (&jr, job_id, job_pid, j->path, err_msg) != 0) {
 		save_errno = errno;
 		destroy_job_run (&jr);
 		errno = save_errno;
