@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -30,9 +30,11 @@ extern "C" {
 #endif
 
 #if HAVE_PID_T
-extern void launcher_main OF((pid_t child, const char *job_id));
+extern void launcher_main OF((	pid_t child, const char *job_id,
+				const char *job_name, char open_log));
 #else
-extern void launcher_main OF((int child, const char *job_id));
+extern void launcher_main OF((	int child, const char *job_id,
+				const char *job_name, char open_log));
 #endif
 
 #ifdef __cplusplus
