@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -17,8 +17,9 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/*
- * lwc_linkedlist.c -- Linked list functions
+/**
+ * @file lwc_linkedlist.c
+ * Linked list functions
  */
 
 #include <schedwi.h>
@@ -31,43 +32,42 @@
 #include <assert.h>
 #endif
 
+#include <xmem.h>
 #include <lwc_linkedlist.h>
 
 
-/*
+/**
  * Create a new linked list
  *
- * Return:
- *   A pointer to the newly allocated linked list object or
- *   NULL in case of malloc error
+ * @return A pointer to the newly allocated linked list object
  */
 lwc_LL *
 lwc_newLL ()
 {
 	lwc_LL *ptr;
 
-	ptr = (lwc_LL *)malloc (sizeof (lwc_LL));
-	if (ptr == (lwc_LL *)0) {
-		return (lwc_LL *)0;
-	}
 
+	ptr = (lwc_LL *) xmalloc (sizeof (lwc_LL));
 	ptr->start = (struct _lwc_linkedNode *)0;
-	ptr->end   = (struct _lwc_linkedNode *)0;
-	ptr->ptr   = (struct _lwc_linkedNode *)0;
-	ptr->num   = 0;
-
+	ptr->end = (struct _lwc_linkedNode *)0;
+	ptr->ptr = (struct _lwc_linkedNode *)0;
+	ptr->num = 0;
 	return ptr;
 }
 
-/*
+/**
  * Destroy a linked list object and all its items (if deleteNote function
  * is not NULL)
+ *
+ * @param ptr The pointer to the linked list.
+ * @param deleteNode A function to call to free each item of the list.
  */
 void
 lwc_delLL (lwc_LL *ptr, void (*deleteNode)(const void *))
 {
 	struct _lwc_linkedNode *node, *save;
 
+
 	if (ptr != (lwc_LL *)0) {
 		node = ptr->start;
 		while (node != (struct _lwc_linkedNode *)0) {
@@ -84,15 +84,19 @@ lwc_delLL (lwc_LL *ptr, void (*deleteNode)(const void *))
 	}
 }
 
-/*
+/**
  * Destroy all nodes of a linked list (if deleteNote function
- * is not NULL, object associated with each node is also destroyed)
+ * is not NULL, objects associated with each node are also destroyed)
+ *
+ * @param ptr The pointer to the linked list.
+ * @param deleteNode A function to call to free each item of the list.
  */
 void
 lwc_emptyLL (lwc_LL *ptr, void (*deleteNode)(const void *))
 {
 	struct _lwc_linkedNode *node, *save;
 
+
 	if (ptr != (lwc_LL *)0) {
 		node = ptr->start;
 		while (node != (struct _lwc_linkedNode *)0) {
@@ -114,8 +118,8 @@ lwc_emptyLL (lwc_LL *ptr, void (*deleteNode)(const void *))
 
 
 
-/*
- * Search and return an item in a sorter list
+/**
+ * Search and return an item in a sorter list.
  * The linked list must be in ascending sorted order (ie. items must be
  * added with the lwc_addLL() or lwc_replaceLL() functions and not with the
  * lwc_addStartLL() or addEndLL() functions).
@@ -124,9 +128,11 @@ lwc_emptyLL (lwc_LL *ptr, void (*deleteNode)(const void *))
  * less than, equal to, or greater than zero if the key object is found,
  * respectively, to be less than, to match, or be greater than the list item.
  *
- * Return:
- *   A pointer to the object found or
- *   NULL if the item is not found
+ *
+ * @param ptr The pointer to the linked list.
+ * @param key The item to look for.
+ * @param compar Comparison function (first parameter is key)
+ * @return A pointer to the object found or NULL if the item is not found.
  */
 void *
 lwc_searchSortLL (lwc_LL *ptr, const void *key,
@@ -135,6 +141,7 @@ lwc_searchSortLL (lwc_LL *ptr, const void *key,
 	struct _lwc_linkedNode *node;
 	int comp_result;
 
+
 	if (ptr == (lwc_LL *) 0) {
 		return (void *)0;
 	}
@@ -154,19 +161,20 @@ lwc_searchSortLL (lwc_LL *ptr, const void *key,
 	return (void *)0;
 }
 
-/*
- * Search and return an item in an unsorted list
- * The linked list do not have to be in ascending sorted order (ie. items can be
- * added with the lwc_addLL(), lwc_replaceLL(), lwc_addStartLL() or addEndLL()
- * functions).
+/**
+ * Search and return an item in an unsorted list.
+ * The linked list do not have to be in ascending sorted order (ie. items can
+ * be added with the lwc_addLL(), lwc_replaceLL(), lwc_addStartLL() or
+ * addEndLL() functions).
  * The compar routine is expected to have two arguments which point to the key
  * object and to an array member, in that order, and should return an integer
  * equal to zero if the key object is found to match a list item or non zero
  * if it does not match.
  *
- * Return:
- *   A pointer to the object found or
- *   NULL if the item is not found
+ * @param ptr The pointer to the linked list.
+ * @param key The item to look for.
+ * @param compar Comparison function (first parameter is key)
+ * @return A pointer to the object found or NULL if the item is not found.
  */
 void *
 lwc_searchLL (lwc_LL *ptr, const void *key,
@@ -174,6 +182,7 @@ lwc_searchLL (lwc_LL *ptr, const void *key,
 {
 	struct _lwc_linkedNode *node;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -190,18 +199,18 @@ lwc_searchLL (lwc_LL *ptr, const void *key,
 }
 
 
-/*
+/**
  * Add a new item in a sorted linked list. The item added must not already
- * exists in the linked list.
+ * exist in the linked list.
  * The compar routine is expected to have two arguments which point to the key
  * object and to an array member, in that order, and should return an integer
  * less than, equal to, or greater than zero if the key object is found,
  * respectively, to be less than, to match, or be greater than the list item.
  *
- * Return:
- *    0 --> Item successfully added
- *   -1 --> malloc error
- *   -2 --> Item already in list
+ * @param ptr The pointer to the linked list.
+ * @param key The item to add.
+ * @param compar Comparison function (first parameter is key)
+ * @return  0 on success or -2 if the item is already in the list.
  */
 int
 lwc_addLL (lwc_LL *ptr, void *key,
@@ -210,6 +219,7 @@ lwc_addLL (lwc_LL *ptr, void *key,
 	struct _lwc_linkedNode *nextNode, *prevNode, *newNode;
 	int comp_result;
 
+
 #if HAVE_ASSERT_H
 	assert (ptr != (lwc_LL *)0);
 #endif
@@ -228,11 +238,8 @@ lwc_addLL (lwc_LL *ptr, void *key,
 		}
 		prevNode = nextNode;
 	}
-	newNode = (struct _lwc_linkedNode *) malloc
+	newNode = (struct _lwc_linkedNode *) xmalloc
 					(sizeof (struct _lwc_linkedNode));
-	if (newNode == (struct _lwc_linkedNode *)0) {
-		return -1;
-	}
 	ptr->num++;
 	newNode->obj  = key;
 	newNode->next = nextNode;
@@ -253,7 +260,7 @@ lwc_addLL (lwc_LL *ptr, void *key,
 }
 
 
-/*
+/**
  * Add a new item in a sorted linked list. If the item is already in list, it
  * is replaced with the new item (key) and the old one is saved in the old
  * parameter (if old is not NULL). If the old parameter is NULL, then the old
@@ -263,10 +270,12 @@ lwc_addLL (lwc_LL *ptr, void *key,
  * less than, equal to, or greater than zero if the key object is found,
  * respectively, to be less than, to match, or be greater than the list item.
  *
- * Return:
- *    0 --> Item successfully added (*old is NULL if no old item is replaced.
- *          Else *old is set to the old object).
- *   -1 --> malloc error
+ * @param ptr The pointer to the linked list.
+ * @param key The item to add.
+ * @param compar Comparison function (first parameter is key)
+ * @param[out] old The replaced item.
+ * @return Always 0 (*old is NULL if no old item is replaced. Else *old is set
+ *         to the old object).
  */
 int
 lwc_replaceLL (lwc_LL *ptr, void *key,
@@ -276,6 +285,7 @@ lwc_replaceLL (lwc_LL *ptr, void *key,
 	struct _lwc_linkedNode *nextNode, *prevNode, *newNode;
 	int comp_result;
 
+
 #if HAVE_ASSERT_H
 	assert (ptr != (lwc_LL *)0);
 #endif
@@ -298,11 +308,8 @@ lwc_replaceLL (lwc_LL *ptr, void *key,
 		}
 		prevNode = nextNode;
 	}
-	newNode = (struct _lwc_linkedNode *) malloc
+	newNode = (struct _lwc_linkedNode *) xmalloc
 					(sizeof (struct _lwc_linkedNode));
-	if (newNode == (struct _lwc_linkedNode *)0) {
-		return -1;
-	}
 	ptr->num++;
 	newNode->obj  = key;
 	newNode->next = nextNode;
@@ -326,7 +333,7 @@ lwc_replaceLL (lwc_LL *ptr, void *key,
 }
 
 
-/*
+/**
  * Add a new item in an unsorted linked list. If the item is already in list,
  * it is replaced with the new item (key) and the old one is saved in the old
  * parameter (if old is not NULL). If the old parameter is NULL, then the old
@@ -336,10 +343,12 @@ lwc_replaceLL (lwc_LL *ptr, void *key,
  * equal to, or different from zero if the key object is found,
  * respectively, to match, or to not match the list item.
  *
- * Return:
- *    0 --> Item successfully added (*old is NULL if no old item is replaced.
- *          Else *old is set to the old object).
- *   -1 --> malloc error
+ * @param ptr The pointer to the linked list.
+ * @param key The item to add.
+ * @param compar Comparison function (first parameter is key)
+ * @param[out] old The replaced item.
+ * @return Always 0 (*old is NULL if no old item is replaced. Else *old is set
+ *         to the old object).
  */
 int
 lwc_replaceUnsortedLL (lwc_LL *ptr, void *key,
@@ -349,6 +358,7 @@ lwc_replaceUnsortedLL (lwc_LL *ptr, void *key,
 	struct _lwc_linkedNode *nextNode, *prevNode, *newNode;
 	int comp_result;
 
+
 #if HAVE_ASSERT_H
 	assert (ptr != (lwc_LL *)0);
 #endif
@@ -368,11 +378,8 @@ lwc_replaceUnsortedLL (lwc_LL *ptr, void *key,
 		}
 		prevNode = nextNode;
 	}
-	newNode = (struct _lwc_linkedNode *) malloc
+	newNode = (struct _lwc_linkedNode *) xmalloc
 					(sizeof (struct _lwc_linkedNode));
-	if (newNode == (struct _lwc_linkedNode *)0) {
-		return -1;
-	}
 	ptr->num++;
 	newNode->obj  = key;
 	newNode->next = (struct _lwc_linkedNode *)0;
@@ -391,27 +398,25 @@ lwc_replaceUnsortedLL (lwc_LL *ptr, void *key,
 }
 
 
-/*
- * Add an item at the begining of the linked list
+/**
+ * Add an item at the begining of the linked list.
  *
- * Return:
- *   0 --> Item successfully added
- *  -1 --> malloc error
+ * @param ptr The pointer to the linked list.
+ * @param key The item to add.
+ * @return Always 0.
  */
 int
 lwc_addStartLL (lwc_LL *ptr, void *key)
 {
 	struct _lwc_linkedNode * newNode;
 
+
 #if HAVE_ASSERT_H
 	assert (ptr != (lwc_LL *)0);
 #endif
 
-	newNode = (struct _lwc_linkedNode *) malloc
+	newNode = (struct _lwc_linkedNode *) xmalloc
 					(sizeof (struct _lwc_linkedNode));
-	if (newNode == (struct _lwc_linkedNode *)0) {
-		return -1;
-	}
 	ptr->num++;
 	newNode->obj  = key;
 	newNode->next = ptr->start;
@@ -426,27 +431,25 @@ lwc_addStartLL (lwc_LL *ptr, void *key)
 	return 0;
 }
 
-/*
- * Add an item at the end of the linked list
+/**
+ * Add an item at the end of the linked list.
  *
- * Return:
- *   0 --> Item successfully added
- *  -1 --> malloc error
+ * @param ptr The pointer to the linked list.
+ * @param key The item to add.
+ * @return Always 0.
  */
 int
 lwc_addEndLL (lwc_LL *ptr, void *key)
 {
 	struct _lwc_linkedNode *newNode;
 
+
 #if HAVE_ASSERT_H
 	assert (ptr != (lwc_LL *)0);
 #endif
 
-	newNode = (struct _lwc_linkedNode *) malloc
+	newNode = (struct _lwc_linkedNode *) xmalloc
 					(sizeof (struct _lwc_linkedNode));
-	if (newNode == (struct _lwc_linkedNode *)0) {
-		return -1;
-	}
 	ptr->num++;
 	newNode->obj  = key;
 
@@ -462,12 +465,12 @@ lwc_addEndLL (lwc_LL *ptr, void *key)
 	return 0;
 }
 
-/*
- * Delete the first node of the linked list and return the associated object
+/**
+ * Delete the first node of the linked list and return the associated object.
  *
- * Return:
- *   A pointer to the object associated with the deleted node or
- *   NULL if there is no item in the list
+ * @param ptr The pointer to the linked list.
+ * @return A pointer to the object associated with the deleted node or
+ *         NULL if there is no item in the list.
  */
 void *
 lwc_delStartLL (lwc_LL *ptr)
@@ -475,6 +478,7 @@ lwc_delStartLL (lwc_LL *ptr)
 	void *item;
 	struct _lwc_linkedNode *delNode;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -504,12 +508,12 @@ lwc_delStartLL (lwc_LL *ptr)
 
 }
 
-/*
- * Delete the last node of the linked list and return the associated object
+/**
+ * Delete the last node of the linked list and return the associated object.
  *
- * Return:
- *   A pointer to the object associated with the deleted node or
- *   NULL if there is no item in the list
+ * @param ptr The pointer to the linked list.
+ * @return A pointer to the object associated with the deleted node or
+ *         NULL if there is no item in the list.
  */
 void *
 lwc_delEndLL (lwc_LL *ptr)
@@ -517,6 +521,7 @@ lwc_delEndLL (lwc_LL *ptr)
 	void *item;
 	struct _lwc_linkedNode *delNode;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -546,7 +551,7 @@ lwc_delEndLL (lwc_LL *ptr)
 
 }
 
-/*
+/**
  * Delete an item from a sorted linked list and return the associated object
  * (or NULL if the key cannot be found).
  * The compar routine is expected to have two arguments which point to the key
@@ -554,9 +559,11 @@ lwc_delEndLL (lwc_LL *ptr)
  * less than, equal to, or greater than zero if the key object is found,
  * respectively, to be less than, to match, or be greater than the list item.
  *
- * Return:
- *  The object associated with the deleted item or
- *  NULL if the key is not found
+ * @param ptr The pointer to the linked list.
+ * @param key The item to remove.
+ * @param compar Comparison function (first parameter is key)
+ * @return A pointer to the object associated with the deleted node or
+ *         NULL if the key is not found.
  */
 void *
 lwc_delNodeLL (lwc_LL *ptr, const void *key,
@@ -566,6 +573,7 @@ lwc_delNodeLL (lwc_LL *ptr, const void *key,
 	int comp_result;
 	void *item = (void *)0;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -606,16 +614,18 @@ lwc_delNodeLL (lwc_LL *ptr, const void *key,
 	return item;
 }
 
-/*
+/**
  * Delete an item from an unsorted linked list and return the associated object
  * (or NULL if the key cannot be found).
  * The compar routine is expected to have two arguments which point to the key
  * object and to an array member, in that order, and should return an integer
  * equal to zero if the key object match the list item.
  *
- * Return:
- *  The object associated with the deleted item or
- *  NULL if the key is not found
+ * @param ptr The pointer to the linked list.
+ * @param key The item to remove.
+ * @param compar Comparison function (first parameter is key)
+ * @return A pointer to the object associated with the deleted node or
+ *         NULL if the key is not found.
  */
 void *
 lwc_delUnsortedNodeLL (lwc_LL *ptr, const void *key,
@@ -625,6 +635,7 @@ lwc_delUnsortedNodeLL (lwc_LL *ptr, const void *key,
 	int comp_result;
 	void *item = (void *)0;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -662,13 +673,15 @@ lwc_delUnsortedNodeLL (lwc_LL *ptr, const void *key,
 	return item;
 }
 
-/*
+/**
  * Set the access pointer to the begining of the list.
  * This function with the next one (lwc_nextLL()) is used to sequentially
  * access all items of the linked list.
  * Deletion, insertion and searching of items (lwc_delNodeLL(), lwc_addLL(),
  * lwc_searchLL(), ...) are allowed while 'visiting' the linked list with
  * lwc_rewindLL() and lwc_nextLL().
+ *
+ * @param ptr The pointer to the linked list.
  */
 void
 lwc_rewindLL (lwc_LL *ptr)
@@ -678,18 +691,19 @@ lwc_rewindLL (lwc_LL *ptr)
 	}
 }
 
-/*
- * Return the next object of the linked list
+/**
+ * Return the next object of the linked list.
  *
- * Return:
- *   A pointer to the next object or
- *   NULL if no more objects are found (end of list is reached).
+ * @param ptr The pointer to the linked list.
+ * @return A pointer to the next object or NULL if no more objects are found
+ *         (end of list reached).
  */
 void *
 lwc_nextLL (lwc_LL *ptr)
 {
 	struct _lwc_linkedNode *toReturn;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -704,15 +718,14 @@ lwc_nextLL (lwc_LL *ptr)
 	}
 }
 
-
-/*
+/**
  * Delete the item at the current position in the list (see lwc_rewindLL()
  * and lwc_nextLL()) and return the associated object (or NULL if the position
  * is not set. ie lwc_nextLL() has not been called yet)
  *
- * Return:
- *  The object associated with the deleted item or
- *  NULL if the position is not set
+ * @param ptr The pointer to the linked list.
+ * @return The object associated with the deleted item or NULL if the position
+ *         is not set.
  */
 void *
 lwc_delCurrentLL (lwc_LL *ptr)
@@ -720,6 +733,7 @@ lwc_delCurrentLL (lwc_LL *ptr)
 	struct _lwc_linkedNode *toDelete;
 	void *item;
 
+
 	if (ptr == (lwc_LL *)0) {
 		return (void *)0;
 	}
@@ -735,7 +749,7 @@ lwc_delCurrentLL (lwc_LL *ptr)
 	}
 
 	item = toDelete->obj;
-	
+
 	if (toDelete->prev == (struct _lwc_linkedNode *)0) {
 		ptr->start = toDelete->next;
 	}
@@ -754,8 +768,11 @@ lwc_delCurrentLL (lwc_LL *ptr)
 }
 
 
-/*
+/**
  * Concatenate two unsorted lists (add src at the end of dst and empty src)
+ *
+ * @param src The pointer to the first linked list (which will be emptied)
+ * @param dst The pointer to the destination linked list.
  */
 void
 lwc_concatUnsortedLL (lwc_LL *src, lwc_LL *dst)
