@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2014 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -43,9 +43,10 @@ extern int  lwc_newLog   OF((	const char * ident,
 				int facility,
 				const char * logFileName,
 				const char * dateFmt));
-extern int  lwc_closeLog OF(());
+extern void  lwc_closeLog OF(());
 extern void lwc_writeLog OF((int level, const char * format, ...));
 extern void lwc_vwriteLog OF((int level, const char * format, va_list ap));
+extern int lwc_logIsFile OF(());
 
 #ifdef __cplusplus
 }
