@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -33,7 +33,7 @@ extern "C" {
 
 extern int (*net_module OF((const char *module_name)))
 			OF((net_id *, char *, size_t));
-extern int add_module OF((	const char *module_name,
+extern void add_module OF((	const char *module_name,
 				int (*module)(net_id *, char *, size_t)));
 extern void destroy_modules OF(());
 
