@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -30,19 +30,14 @@
 #include <net_module.h>
 #include <net_module_clnt.h>
 
-int
+void
 module_load_clnt ()
 {
-	if (	   add_module ("runjob", run_job) != 0
-		|| add_module ("killjob", kill_jobs) != 0
-		|| add_module ("testfile", test_file) != 0
-		|| add_module ("joblist", get_joblist) != 0
-		|| add_module ("version", get_version) != 0)
-	{
-		destroy_modules ();
-		return -1;
-	}
-	return 0;
+	add_module ("runjob", run_job);
+	add_module ("killjob", kill_jobs);
+	add_module ("testfile", test_file);
+	add_module ("joblist", get_joblist);
+	add_module ("version", get_version);
 }
 
 /*-----------------============== End Of File ==============-----------------*/
