@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -29,7 +29,7 @@
 extern "C" {
 #endif
 
-extern int module_load_clnt OF(());
+extern void module_load_clnt OF(());
 
 #ifdef __cplusplus
 }
