@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -24,8 +24,8 @@
 
 #include <schedwi.h>
 
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
+#if HAVE_SYS_SELECT_H
+#include <sys/select.h>
 #endif
 
 #if HAVE_LIBGNUTLS
@@ -42,19 +42,21 @@ struct _net_id {
 	gnutls_session_t session;
 #endif
 	int sock;
+	fd_set sock_set;
+	int sock_max;
 };
 typedef struct _net_id net_id;
 
 extern int net_server OF((	net_id *id, const char *port_number,
-				const char *iface));
+				const char *iface, const char *address_family));
 extern int net_accept OF((	net_id *id, net_id *new_id,
-				const char *schedwi_server_name));
+				const char *schedwi_server_name,
+				const char *allow_from));
 extern int net_client OF((	net_id *id, const char *port_number,
 				const char *hostname));
 extern ssize_t net_read OF((net_id *id, char **buff, size_t *len));
 extern int net_read_result OF((net_id *id, char **result_msg));
 extern int net_write OF((net_id *id, const char *buff, size_t len));
-extern int net_write_eof OF((net_id *id));
 extern int net_close OF((net_id *id));
 
 #ifdef __cplusplus
