@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@ extern "C" {
 #endif
 
 extern int net_init OF((const char *client_crt, const char *client_key,
-			const char *server_crt, char quick_random));
+			const char *server_crt, char quick_random, char ssl));
 extern int net_init_server OF(());
 extern void net_free OF(());
 extern char ssl_enabled OF(());
