@@ -1134,7 +1134,7 @@ net_read_sock (int sock, char **buff, size_t *len)
 		 * been received.
 		 */
 		for (i = 0; i < nb_read; i++) {
-			if (! JSON_parser_char (jc, b[i])) {
+			if (! JSON_parser_char (jc, (unsigned char)(b[i]))) {
 				lwc_writeLog (	LOG_ERR,
 					_("Syntax error in received data"));
 				delete_JSON_parser (jc);
