@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2013 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -500,6 +500,8 @@ int
 net_client_ssl (int fd, gnutls_session_t *session, const char *server_hostname)
 {
 	int ret;
+	static char num_errors = 0;
+
 
 #if HAVE_ASSERT_H
 	assert (server_hostname != NULL && session != NULL);
@@ -537,13 +539,22 @@ net_client_ssl (int fd, gnutls_session_t *session, const char *server_hostname)
 		ret = gnutls_handshake (*session);
 	} while (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED);
 	if (ret < 0) {
-		lwc_writeLog (LOG_ERR,
+		/*
+		 * Do not report all the handshake errors "Error in the pull
+		 * function" (a retry will occur later).  When the server is
+		 * under load, the GnuTLS handshake fails from time to time.
+		 */
+		if (++num_errors > 3) {
+			num_errors = 0;
+			lwc_writeLog (LOG_WARNING,
 			_("SSL: Connection handshake failed with %s: %s"),
-			server_hostname, gnutls_strerror (ret));
+				server_hostname, gnutls_strerror (ret));
+		}
 		gnutls_bye (*session, GNUTLS_SHUT_RDWR);
 		gnutls_deinit (*session);
 		return -1;
 	}
+	num_errors = 0;
 
 	/* Check the certificate */
 	if (net_utils_ssl_check_certificate (session, server_hostname) != 0) {
@@ -661,7 +672,7 @@ net_read_ssl (gnutls_session_t session, char **buff, size_t *len)
 		 * been receved.
 		 */
 		for (i = 0; i < nb_read; i++) {
-			if (! JSON_parser_char (jc, b[i])) {
+			if (! JSON_parser_char (jc, (unsigned char)(b[i]))) {
 				lwc_writeLog (	LOG_ERR,
 					_("Syntax error in received data"));
 				delete_JSON_parser (jc);
