@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -26,6 +26,10 @@
 #include <config.h>
 #endif
 
+#if HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -48,6 +52,14 @@
 #endif /* not ENABLE_NLS && HAVE_GETTEXT */
 #define N_(string) string
 
+/* Some systems do not define EXIT_*, even with STDC_HEADERS.  */
+#if !defined(EXIT_SUCCESS)
+# define EXIT_SUCCESS 0
+#endif
+#if !defined(EXIT_FAILURE)
+# define EXIT_FAILURE 1
+#endif
+
 #ifndef HAVE_SIZE_T
 typedef unsigned int size_t;
 #endif
