@@ -32,7 +32,7 @@
 extern "C" {
 #endif
 
-extern int send_process_start OF(());
+extern int send_process_start OF((char open_log));
 extern void send_process_stop OF(());
 extern void send_process_wakeup OF(());
 extern void send_process_term OF(());
