@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007-2011 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -21,6 +21,10 @@
 
 #include <schedwi.h>
 
+#if HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
 #if STDC_HEADERS
 #include <stdlib.h>
 #include <string.h>
@@ -69,6 +73,7 @@ extern int errno;
 #endif
 
 #include <lib_functions.h>
+#include <xmem.h>
 #include <utils.h>
 
 #if _GNU_SOURCE && !HAVE_CLEARENV
@@ -125,12 +130,13 @@ base_name (const char *path)
 	const char * s, * prev;
 	size_t sep_length;
 
+
 #ifdef HAVE_ASSERT_H
 	assert (path != 0);
 #endif
 	prev = 0;
 	s    = path;
-	sep_length = schedwi_strlen (DIR_SEP);
+	sep_length = strlen (DIR_SEP);
 	while ((s = strstr (s, DIR_SEP)) != 0) {
 		s += sep_length;
 		prev = s;
@@ -228,15 +234,16 @@ sanitise (int fd)
 	struct sigaction sa;
 	sigset_t mask;
 
+
 	/* Close all files (except fd) */
-	for (i = getdtablesize () - 1; i >= 0; i--) {
+	for (i = getdtablesize () - 1; i >= 3; i--) {
 		if (i != fd) {
 			close (i);
 		}
 	}
 
 	/* Clear the environment */
-#ifndef CYGWIN_IN_USE
+#if !defined CYGWIN_IN_USE && !defined NETBSD_IN_USE
 #if HAVE_CLEARENV
 	clearenv ();
 #elif _GNU_SOURCE
@@ -262,29 +269,9 @@ sanitise (int fd)
 void
 clean_process ()
 {
-	int unused;
-#if HAVE_GETENV && HAVE_CHDIR
-	char *tmp;
-#endif
-
-	/* Change to a temporary directory */
-	tmp = NULL;
+	/* Change default directory to `/' */
 #if HAVE_CHDIR
-#if HAVE_GETENV
-	tmp = getenv ("TMPDIR");
-	if (tmp != NULL) {
-		if (chdir (tmp) != 0) {
-			tmp = NULL;
-		}
-	}
-#endif /* HAVE_GETENV */
-	if (tmp == NULL) {
-#ifdef P_tmpdir
-		unused = chdir (P_tmpdir);
-#else
-		unused = chdir ("/tmp");
-#endif
-	}
+	(void)chdir ("/");
 #endif /* HAVE_CHDIR */
 
 	/* Clean the process */
@@ -312,6 +299,7 @@ go_daemon()
 	int p;
 #endif
 
+
 	p = fork ();
 	if (p < 0) {
 		return -1;
@@ -329,7 +317,66 @@ go_daemon()
 }
 
 
+/*
+ * Create the intermediate directories leading to `file_path'.  The last
+ * component is not created.
+ *
+ * @param[in] file_path Full file name.
+ * @return 0 on success,
+ *        -1 if one component already exists and is not a directory or
+ *        -2 on failure to create a directory (errno is set)
+ */
+int
+mkpath (const char *file_path)
+{
+#if HAVE_MKDIR
+	char *path, *p;
+	size_t sep_length;
+	struct stat stat_str;
+	int save_errno;
+
+
+#ifdef HAVE_ASSERT_H
+	assert (file_path != NULL && file_path[0] != '\0');
+#endif
+
+	path = (char *) xmalloc (strlen (file_path) + 1);
+	strcpy (path, file_path);
+
+	sep_length = strlen (DIR_SEP);
+	for (p = strstr (path, DIR_SEP);
+	     p != NULL;
+	     p = strstr (p + sep_length, DIR_SEP))
+	{
+		if (p == path) {
+			continue;
+		}
+		*p = '\0';
+		if (stat (path, &stat_str) == 0) {
+			if (S_ISDIR (stat_str.st_mode) == 0) {
+				/* Not a directory */
+				free (path);
+				return -1;
+			}
+			*p = DIR_SEP[0];
+			continue;
+		}
+		if (mkdir (path, 0755) != 0) {
+			save_errno = errno;
+			free (path);
+			errno = save_errno;
+			return -2;
+		}
+		*p = DIR_SEP[0];
+	}
+	free (path);
+#endif /* HAVE_MKDIR */
+	return 0;
+}
+
+
 static int fd_pid_file = -1;
+static char *pid_file_name = NULL;
 
 /*
  * Write the PID of the current process to the provided file.
@@ -343,13 +390,21 @@ int
 write_pid_file (const char *file_name)
 {
 	char pid_str[26];
-	size_t l;
-	ssize_t unused;
 
-	if (file_name == NULL) {
+
+	if (file_name == NULL || file_name[0] == '\0') {
 		return 0;
 	}
 
+	if (pid_file_name != NULL) {
+		close_pid_file ();
+	}
+	pid_file_name = (char *) xmalloc (strlen (file_name) + 1);
+	strcpy (pid_file_name, file_name);
+
+	/* If need be, create the intermediate directories */
+	mkpath (file_name);
+
 	/* Open the PID file */
 	fd_pid_file = open (file_name, O_RDWR|O_CREAT, 00644);
 	if (fd_pid_file < 0) {
@@ -371,9 +426,9 @@ write_pid_file (const char *file_name)
 #endif
 
 	/* Write the PID to the file */
-	l = snprintf (pid_str, 26, "%ld\n", (long int)getpid ());
+	snprintf (pid_str, 26, "%ld\n", (long int)getpid ());
 	pid_str [26 - 1] = '\0';
-	unused = write (fd_pid_file, pid_str, schedwi_strlen (pid_str));
+	write (fd_pid_file, pid_str, strlen (pid_str));
 	return 0;
 }
 
@@ -382,10 +437,12 @@ write_pid_file (const char *file_name)
  * Close and remove the file containing the PID of the daemon
  */
 void
-close_pid_file (const char *file_name)
+close_pid_file ()
 {
-	if (file_name != NULL) {
-		my_unlink (file_name);
+	if (pid_file_name != NULL) {
+		my_unlink (pid_file_name);
+		free (pid_file_name);
+		pid_file_name = NULL;
 	}
 
 	if (fd_pid_file >= 0) {
@@ -394,4 +451,88 @@ close_pid_file (const char *file_name)
 	fd_pid_file = -1;
 }
 
+
+/*
+ * Split the given jobid string into the workload part and the job ID part.
+ *
+ * Return:
+ *    The job ID as a string and the workload in `workload' (if not NULL)
+ */
+char *
+split_jobid (const char *jobid, int *workload)
+{
+	int wl;
+	char *s;
+
+
+	wl = strtol (jobid, &s, 0);
+	if (workload != NULL) {
+		*workload = wl;
+	}
+	if (*s != '\0') {
+		s++;
+	}
+	return s;
+}
+
+
+/*
+ * Read a file and return a newly allocated string with the content,
+ * and set `*length' to the length of the string.  The string is
+ * zero-terminated, but the terminating zero byte is not counted in
+ * `*length'.
+ *
+ * Return:
+ *   The content of the file (to be freed by free()) OR
+ *   NULL in case of error (errno is set and `*length' is undefined)
+ */
+char *
+read_file (const char *filename, size_t *length)
+{
+	struct stat stat_str;
+	FILE *f;
+	char *file_content;
+	size_t nb_read;
+	int save_errno;
+
+
+#if HAVE_ASSERT_H
+	assert (filename != NULL);
+#endif
+
+	/* Retrieve the file size */
+	if (stat (filename, &stat_str) != 0) {
+		return NULL;
+	}
+
+	/* Create a buffer for reading the whole file */
+	file_content = (char *) xmalloc (stat_str.st_size + 1);
+
+	/* Open and read the whole file */
+	f = fopen (filename, "rb");
+	if (f == NULL) {
+		save_errno = errno;
+		free (file_content);
+		errno = save_errno;
+		return NULL;
+	}
+
+	clearerr (f);
+	nb_read  = fread (file_content, 1, stat_str.st_size, f);
+	if (nb_read != stat_str.st_size && ferror (f) != 0) {
+		save_errno = errno;
+		fclose (f);
+		free (file_content);
+		errno = save_errno;
+		return NULL;
+	}
+	fclose (f);
+
+	file_content[stat_str.st_size] = '\0';
+	if (length != NULL) {
+		*length = stat_str.st_size;
+	}
+	return file_content;
+}
+
 /*------------------------======= End Of File =======------------------------*/
