@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2015 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -36,8 +36,11 @@ extern int my_unlink OF((const char *file_name));
 extern void sanitise OF((int fd));
 extern void clean_process OF(());
 extern int go_daemon OF(());
+extern int mkpath OF((const char *file_path));
 extern int write_pid_file OF((const char *file_name));
-extern void close_pid_file OF((const char *file_name));
+extern void close_pid_file OF(());
+extern char *split_jobid OF((const char *jobid, int *workload));
+extern char *read_file OF((const char *filename, size_t *length));
 
 #ifdef __cplusplus
 }
