@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2010 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -162,16 +162,7 @@ send_version ()
 	}
 
 	/* Build and send the header */
-	schedwi_memset (buff, 0, 25);
-	buff[0] = 'v';
-	buff[1] = 'e';
-	buff[2] = 'r';
-	buff[3] = 's';
-	buff[4] = 'i';
-	buff[5] = 'o';
-	buff[6] = 'n';
-	send (sock, buff, 25, 0);
-	send (sock, "\nbYe", 4, 0); 
+	send (sock, "[ \"version\" ]", 13, 0);
 
 	/* Read the reply and dump it to stdout */
 	do{
